==> amps-java-client-5.3.0.1.tar.gz: amps-java-client-5.3.0.1/src/com/crankuptheamps/client/ClientDisconnectHandler.java <==
////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2012-2019 60East Technologies Inc., All Rights Reserved.
//
// This computer software is owned by 60East Technologies Inc. and is
// protected by U.S. copyright laws and other laws and by international
// treaties.  This computer software is furnished by 60East Technologies
// Inc. pursuant to a written license agreement and may be used, copied,
// transmitted, and stored only in accordance with the terms of such
// license agreement and with the inclusion of the above copyright notice.
// This computer software or any other copies thereof may not be provided
// or otherwise made available to any other person.
//
// U.S. Government Restricted Rights.  This computer software: (a) was
// developed at private expense and is in all respects the proprietary
// information of 60East Technologies Inc.; (b) was not developed with
// government funds; (c) is a trade secret of 60East Technologies Inc.
// for all purposes of the Freedom of Information Act; and (d) is a
// commercial item and thus, pursuant to Section 12.212 of the Federal
// Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
// Government's use, duplication or disclosure of the computer software
// is subject to the restrictions set forth by 60East Technologies Inc..
//
////////////////////////////////////////////////////////////////////////////

package com.crankuptheamps.client;

/**
 * Called in {@link Client} when the Client unintentionally disconnects
 * from AMPS. This interface can be used to implement your own disconnect handler.
 * It will notify you that a Client disconnected so that action can be taken, such
 * as doing a reconnect. 
 */
public interface ClientDisconnectHandler
{
    /**
     * When the Client unintentionally disconnects from AMPS, this method is
     * invoked.
     * @param client The client that unintentionally disconnected from AMPS.
     */
    public void invoke(Client client);
}

==> amps-java-client-5.3.4.1.tar.gz: amps-java-client-5.3.4.1/src/com/crankuptheamps/client/ClientDisconnectHandler.java <==
////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2012-2025 60East Technologies Inc., All Rights Reserved.
//
// This computer software is owned by 60East Technologies Inc. and is
// protected by U.S. copyright laws and other laws and by international
// treaties.  This computer software is furnished by 60East Technologies
// Inc. pursuant to a written license agreement and may be used, copied,
// transmitted, and stored only in accordance with the terms of such
// license agreement and with the inclusion of the above copyright notice.
// This computer software or any other copies thereof may not be provided
// or otherwise made available to any other person.
//
// U.S. Government Restricted Rights.  This computer software: (a) was
// developed at private expense and is in all respects the proprietary
// information of 60East Technologies Inc.; (b) was not developed with
// government funds; (c) is a trade secret of 60East Technologies Inc.
// for all purposes of the Freedom of Information Act; and (d) is a
// commercial item and thus, pursuant to Section 12.212 of the Federal
// Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
// Government's use, duplication or disclosure of the computer software
// is subject to the restrictions set forth by 60East Technologies Inc..
//
////////////////////////////////////////////////////////////////////////////

package com.crankuptheamps.client;

/**
 * Called in {@link Client} when the Client unintentionally disconnects
 * from AMPS. This interface can be used to implement your own disconnect handler.
 * It will notify you that a Client disconnected so that an action can be taken, such
 * as doing a reconnect. 
 */
public interface ClientDisconnectHandler
{
    /**
     * When the Client unintentionally disconnects from AMPS, this method is
     * invoked.
     * @param client The client that unintentionally disconnected from AMPS.
     */
    public void invoke(Client client);
}
